package
Version:
v0.0.0-...-f54c1c2
Opens a new window with list of versions in this module.
Published: Oct 18, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Discovery struct {
}
Discovery godoc
@Description Discovers new Printers
@Tags discovery
@Accept application/json
@Produce application/json
@Success 200 {object} models.DiscoveryResponse
@Failure 500 {string} string
@Router /discovery [post]
Source Files
¶
Click to show internal directories.
Click to hide internal directories.